<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 *
 * @package   theme_mb2aofk
 * @copyright 2019 - 2020 Mariusz Boloz (https://mb2themes.com)
 * @license   Commercial https://themeforest.net/licenses
 *
 */

defined('MOODLE_INTERNAL') || die();



/*
 *
 * Method to get course banner
 *
 */
function theme_mb2aofk_course_banner ()
{

	global $CFG, $COURSE, $PAGE, $OUTPUT;

	$output = '';
	$bannerUrl = '';
	$cls = ' noimage';
	$banner = theme_mb2aofk_theme_setting( $PAGE, 'banner' );
	$cname = theme_mb2aofk_theme_setting( $PAGE, 'cbannername' );
	$banner_url = theme_mb2aofk_course_banner_url();

	$coursemenu = $OUTPUT->context_header_settings_menu();
	$modmenu = $OUTPUT->region_main_settings_menu();
	$showheadingbuttons = ( ! $coursemenu && $OUTPUT->page_heading_button() );

	if ($banner_url)
	{
		$cls = ' isimage';
	}

	$output .= '<div class="theme-banner' . $cls . '">';
	$output .= '<div class="container-fluid">';
	$output .= '<div class="row">';
	$output .= '<div class="col-md-12">';

	$output .= '<div class="banner-inner clearfix">';
	$output .= '<div class="banner-left">';

	$output .= '<div class="breadcrumb">' . $OUTPUT->navbar() . '</div>';

	if ( $cname && $COURSE->id > 1 )
	{
		$output .= '<h1 class="h4"><a href="' . new moodle_url( $CFG->wwwroot . '/course/view.php',array( 'id'=> $COURSE->id ) ) . '">' . $COURSE->fullname . '</a></h1>';
	}

	$output .= '</div>';

	$output .= '<div class="banner-right">';
	$output .= theme_mb2aofk_header_actions();
	if ( ! theme_mb2aofk_theme_setting( $PAGE, 'coursepanel' ) )
	{
		if ( $coursemenu || $modmenu )
		{
			$output .= $coursemenu . $modmenu;
		}
	}
	if ( $showheadingbuttons )
	{
		$output .= $OUTPUT->page_heading_button();
	}

	$output .= '</div>';
	$output .= '</div>';
	$output .= $banner_url ? '<div class="banner-bg" style="background-image:url(\'' . $banner_url  . '\');"></div>' : '';
	$output .= '<div class="banner-bg-color"></div>';

	$output .= '</div>';
	$output .= '</div>';
	$output .= '</div>';
	$output .= '</div>';

	return $output;

}







/*
 *
 * Method to get course banner url
 *
 */
function theme_mb2aofk_course_banner_url ()
{

	global $CFG, $COURSE, $PAGE, $OUTPUT;

	$output = '';
	$course_img = theme_mb2aofk_course_image_url($COURSE->id);
	$banner = theme_mb2aofk_theme_setting($PAGE,'banner');

	if ($COURSE->id > 1 && theme_mb2aofk_theme_setting($PAGE,'cbannerimg') && $course_img)
	{
		$output = $course_img;
	}
	elseif ($banner && theme_mb2aofk_theme_setting($PAGE, 'bannerimg', '', true) !='')
	{
		$output = theme_mb2aofk_theme_setting($PAGE, 'bannerimg', '', true);
	}
	elseif ($banner)
	{
		$banner_def_img = theme_mb2aofk_moodle_from(2017051500) ? $OUTPUT->image_url('default-banner','theme') : $OUTPUT->pix_url('default-banner','theme');
		$output = $banner_def_img;
	}

	return $output;

}






/*
 *
 * Method to get image url from course 'overviewfiles' file area
 *
 */
function theme_mb2aofk_course_image_url( $courseid = null )
{
	global $CFG;

	if ( !$courseid )
	{
		return;
	}

	require_once( $CFG->libdir . '/filelib.php' );

	$url = null;
	$context = context_course::instance( $courseid );
	$fs = get_file_storage();
	$files = $fs->get_area_files( $context->id, 'course', 'overviewfiles', 0 );

	foreach ( $files as $f )
	{
		if ( $f->is_valid_image() )
		{
			$url = moodle_url::make_pluginfile_url(
				$f->get_contextid(), $f->get_component(), $f->get_filearea(), null, $f->get_filepath(), $f->get_filename(), false );
		}
	}

	return $url;

}






/*
 *
 * Method to set block class
 *
 *
 */
function theme_mb2aofk_page_cls ($page, $course = false)
{

	$output = '';

	$isPage = $page->pagetype === 'mod-page-view';

	if ($course)
	{
		$pageId = $isPage ? $page->course->id : 0;
		$output .= theme_mb2aofk_line_classes(theme_mb2aofk_theme_setting($page, 'coursecls'), $pageId);
	}
	else
	{
		$pageId = $isPage ? $page->cm->id : 0;
		$output .= theme_mb2aofk_line_classes(theme_mb2aofk_theme_setting($page, 'pagecls'), $pageId);
	}

	return $output;

}







/*
 *
 * Method to set block class
 *
 *
 */
function theme_mb2aofk_course_cls ($page)
{

	$output = '';


	$output .= theme_mb2aofk_line_classes(theme_mb2aofk_theme_setting($page, 'coursescls'), $page->course->id);


	return $output;

}





/*
 *
 * Method to set body class for course category theme
 *
 */
function theme_mb2aofk_courselist_cls($page)
{

	$output = '';

	$isCourse = $page->pagetype === 'course-index';
	$isCourseCat = $page->pagetype === 'course-index-category';
	$catId = ($isCourseCat && isset($page->category->id)) ? $page->category->id : 0;
	$clsPreff = 'coursetheme-';

	if ($catId > 0)
	{
		$output .= $clsPreff . theme_mb2aofk_line_classes(theme_mb2aofk_theme_setting($page, 'coursecattheme'), $catId);
	}
	else
	{
		$output .= $clsPreff . theme_mb2aofk_theme_setting($page, 'coursetheme');
	}

	return $output;

}
