<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 *
 * @package   theme_mb2aofk
 * @copyright 2019 - 2020 Mariusz Boloz (https://mb2themes.com)
 * @license   Commercial https://themeforest.net/licenses
 *
 */


defined('MOODLE_INTERNAL') || die();


/*
 *
 * Method to set body class
 *
 *
 */
function theme_mb2aofk_body_cls($page)
{

	global $PAGE, $USER, $COURSE;
	$output = array();

	// Page layout
	$output[] = 'theme-l' . theme_mb2aofk_theme_setting($page, 'layout', 'fw');

	// Header style
	$output[] = 'header-' . theme_mb2aofk_theme_setting($page, 'headerstyle', 'light');

	// Icon nav menu class
	if (theme_mb2aofk_theme_setting($page, 'navicons') !='')
	{
		$output[] = 'isiconmenu';
	}

	// Custom login page
	if (theme_mb2aofk_is_login($page, true))
	{
		$output[] = 'custom-login';
	}

	// User logged in or logged out (not guest)
	if (isloggedin() && !isguestuser())
	{
		$output[] = 'loggedin';
	}

	// Check if is guest user
	if (isguestuser())
	{
		$output[] = 'isguestuser';
	}

	// Custom page classess
	if (theme_mb2aofk_page_cls($page))
	{
		$output[] = theme_mb2aofk_page_cls($page);
	}

	// Custom course pages class
	if (theme_mb2aofk_page_cls($page, true))
	{
		$output[] = theme_mb2aofk_page_cls($page, true);
	}

	// Custom course class
	if (theme_mb2aofk_course_cls($page))
	{
		$output[] = theme_mb2aofk_course_cls($page);
	}

	// Course category theme
	if (theme_mb2aofk_courselist_cls($page))
	{
		$output[] = theme_mb2aofk_courselist_cls($page);
	}

	// Fixed navigation
	if (theme_mb2aofk_theme_setting($page, 'stickynav', 0))
	{
		$output[] = 'sticky-nav';
	}

	// Page predefined background
	if (!theme_mb2aofk_is_login($page, true) && theme_mb2aofk_theme_setting($page, 'pbgpre') !='')
	{
		$output[] = 'pre-bg' . theme_mb2aofk_theme_setting($page, 'pbgpre');
	}

	// Login page predefined background
	if (theme_mb2aofk_is_login($page, true) && theme_mb2aofk_theme_setting($page, 'loginbgpre') !='')
	{
		$output[] = 'pre-bg' . theme_mb2aofk_theme_setting($page, 'loginbgpre');
	}

	if (theme_mb2aofk_theme_setting($page,'sidebarbtn') == 2)
	{
		$output[] = 'hide-sidebars';
	}

	// Theme hidden region mode
	if (isloggedin() && !is_siteadmin())
	{
		$output[] = 'theme-hidden-region-mode';
	}

	if (!theme_mb2aofk_is_frontpage_content())
	{
		$output[] = 'fpempty';
	}

	if (theme_mb2aofk_course_layout_class())
	{
		$output[] = theme_mb2aofk_course_layout_class();
	}

	// if (theme_mb2aofk_is_module_context())
	// {
	// 	$output[] = 'full-screen';
	// }

	$output[] = theme_mb2aofk_midentify();


	$output[] = theme_mb2aofk_sidebar_cls();

	// User logged in or logged out (not guest)
	if ( (isloggedin() && !isguestuser() ) )
	{
		$output[] = 'loggedin';
		$user_roles = theme_mb2aofk_get_role();

		if ($user_roles)
		{
			foreach ($user_roles as $role)
			{
				$output[] = $role;
			}
		}
	}

	if ( isset($USER->gradeediting[$COURSE->id]) && $PAGE->pagetype === 'grade-report-grader-index' && $USER->gradeediting[$COURSE->id] )
	{
		$output[] = 'grading';
	}

	return $output;

}






/*
 *
 * Method to check if front page is empty
 *
 */
function theme_mb2aofk_sidebar_cls()
{
	global $PAGE;

	$output = 'no-sidebars';
	$sidePre = theme_mb2aofk_isblock($PAGE, 'side-pre');
	$sidePost = theme_mb2aofk_isblock($PAGE, 'side-post');

	if ($sidePre && $sidePost)
	{
		$output = 'two-sidebars';
	}
	elseif ($sidePre || $sidePost)
	{
		$output = 'one-sidebar';
	}

	return $output;

}


/*
 *
 * Method to check if front page is empty
 *
 */
function theme_mb2aofk_is_frontpage_content()
{

	global $CFG;

	if (is_dir($CFG->dirroot . '/local/mb2builder'))
	{
		if ((isloggedin() && !isguestuser()))
		{
			if (($CFG->frontpageloggedin === 'none' || $CFG->frontpageloggedin === ''))
			{
				return false;
			}
		}
		else
		{
			if (($CFG->frontpage === 'none' || $CFG->frontpage === ''))
			{
				return false;
			}
		}
	}

	return true;

}




/*
 *
 * Method to check if is login page
 *
 */
function theme_mb2aofk_is_login($page, $custom = false)
{

	$output = false;


	$pTypeArr = explode('-', $page->pagetype);
	$isLoginPage = ($pTypeArr[0] === 'login' && $pTypeArr[1] === 'index');
	$customLoginPage = theme_mb2aofk_theme_setting($page, 'cloginpage', '', 0);
	$isuserLogged = (isloggedin() && !isguestuser());


	if ($custom)
	{
		$output = ($isLoginPage && $customLoginPage && !$isuserLogged);
	}
	else
	{
		$output = $isLoginPage;
	}


	return $output;


}










/*
 *
 * Method to get theme scripts
 *
 *
 */
function theme_mb2aofk_theme_scripts ($page, $attribs = array())
{

	global $USER, $CFG;

	// Check if Moodle version is 2.9+
	// to use Bootstrap 3 AMD
	$m28 = '2014111012';
	$m29plus = ($CFG->version > $m28);

	// jQuery framework
	$page->requires->jquery();

	// Sf menu script
	$page->requires->js('/theme/mb2aofk/assets/superfish/superfish.custom.js');

	// Main slider
	$page->requires->js('/theme/mb2aofk/assets/lightslider/lightslider.custom.min.js');

	// OWL carousel
	$page->requires->css('/theme/mb2aofk/assets/OwlCarousel/assets/owl.carousel.min.css');
	$page->requires->js('/theme/mb2aofk/assets/OwlCarousel/owl.carousel.min.js');

	// Inview: http://github.com/zuk/jquery.inview/
	$page->requires->js('/theme/mb2aofk/assets/inview.js');

	// Animate number plugin: https://github.com/aishek/jquery-animateNumber
	$page->requires->js('/theme/mb2aofk/assets/animateNumber.js');

	// https://github.com/js-cookie/js-cookie
	$page->requires->js('/theme/mb2aofk/assets/js.cookie.js');

	// Spectrum color
	if (is_siteadmin())
	{
		$page->requires->css('/theme/mb2aofk/assets/spectrum/spectrum.min.css');
		$page->requires->js('/theme/mb2aofk/assets/spectrum/spectrum.min.js');
	}

	// Theme amd script from Boost theme scripts
	// $page->requires->js('/theme/mb2aofk/javascript/theme-amd.js');
	$page->requires->js('/theme/mb2aofk/javascript/theme.js');

	// Youtube api player
	$page->requires->js('/theme/mb2aofk/assets/youtube/player_api.js');

	// Custom scripts
	$cssFiles = theme_mb2aofk_get_custom_files(1);
	$jsFiles = theme_mb2aofk_get_custom_files(2);
	$themename = theme_mb2aofk_themename();

	if (count($cssFiles)>0)
	{
		foreach ($cssFiles as $cssF)
		{
			$page->requires->css('/theme/' . $themename . '/style/custom/' . $cssF . '.css');
		}
	}

	if (count($jsFiles)>0)
	{
		foreach ($jsFiles as $jsF)
		{
			$page->requires->js('/theme/' . $themename . '/javascript/custom/' . $jsF . '.js');
		}
	}

}







/*
 *
 * Method to get theme name
 *
 *
 */
function theme_mb2aofk_themename ()
{
	global $CFG,$PAGE,$COURSE;


	$name = $CFG->theme;


	if (isset($PAGE->theme->name) && $PAGE->theme->name)
	{
		$name = $PAGE->theme->name;
	}
	elseif (isset($COURSE->theme) && $COURSE->theme)
	{
		$name = $COURSE->theme;
	}


	return $name;

}








/*
 *
 * Method to get menu data attributes
 *
 *
 */
function theme_mb2aofk_menu_data ($page, $attribs = array())
{

	$output = '';

	$output .= ' data-animtype="' . theme_mb2aofk_theme_setting($page, 'navatype', 2) . '"';
	$output .= ' data-animspeed="' . theme_mb2aofk_theme_setting($page, 'navaspeed', 300) . '"';
	$output .= ' data-breakpoint="768"';

	return $output;

}


/*
 *
 * Method to get custom css and js file
 *
 *
 */
function theme_mb2aofk_get_custom_files ($type)
{

	global $CFG;


	$themename = theme_mb2aofk_themename();
	$cssDir = $CFG->dirroot . '/theme/' . $themename . '/style/custom/';
	$jsDir = $CFG->dirroot . '/theme/' . $themename . '/javascript/custom/';


	if (is_dir($cssDir) && $type == 1)
	{
		return theme_mb2aofk_file_arr($cssDir, array('css'));
	}
	elseif (is_dir($jsDir) && $type == 2)
	{
		return theme_mb2aofk_file_arr($jsDir, array('js'));
	}

	return array();

}






/*
 *
 * Method to get files array from directory
 *
 *
 */
function theme_mb2aofk_file_arr ($dir, $filter = array('jpg','jpeg','png','gif'))
{

	$output = '';
	$filesArray = array();

	if (!is_dir($dir))
	{
		$output = get_string('foldernoexists','theme_mb2aofk');
	}
	else
	{
		$dirContents = scandir($dir);

		foreach ($dirContents as $file)
		{
			$file_type = pathinfo($file, PATHINFO_EXTENSION);

			if (in_array($file_type, $filter))
			{
				$filesArray[] = basename($file, '.' . $file_type);
			}
		}

		$output = $filesArray;
	}

	return $output;

}








/*
 *
 * Method to get random image from array
 *
 *
 */
function theme_mb2aofk_random_image ($dir, $pixDirName, $attribs = array('jpg','jpeg','png','gif'))
{

	global $OUTPUT, $CFG;

	$moodle33 = 2017051500;

	$output = '';

	$arr = theme_mb2aofk_file_arr($dir, $attribs);


	if (is_array($arr) && !empty($arr))
	{

		$randomImg = array_rand($arr,1);
		$output = $CFG->version >= $moodle33 ? $OUTPUT->image_url($pixDirName . '/' . $arr[$randomImg],'theme') : $OUTPUT->pix_url($pixDirName . '/' . $arr[$randomImg],'theme');

	}


	return $output;



}




/*
 *
 * Method to get font icons
 *
 *
 */
function theme_mb2aofk_font_icon ($page, $attribs = array())
{

	$output = '';

	//$faIcons = theme_mb2aofk_theme_setting($page, 'ficonfa', 1);
	$ficon7stroke = theme_mb2aofk_theme_setting($page, 'ficon7stroke', 1);
	$glyphIcons = theme_mb2aofk_theme_setting($page, 'ficonglyph', 1);

	// if ($faIcons == 1)
	// {
	// 	$page->requires->css('/theme/mb2aofk/assets/font-awesome/css/font-awesome.min.css');
	// }

	if ($ficon7stroke == 1)
	{
		$page->requires->css('/theme/mb2aofk/assets/pe-icon-7-stroke/css/pe-icon-7-stroke.min.css');
	}

	if ($glyphIcons == 1)
	{
		$page->requires->css('/theme/mb2aofk/assets/bootstrap/css/glyphicons.min.css');
	}

	return $output;

}






/*
 *
 * Method to get image url
 *
 *
 */
function theme_mb2aofk_pluginfile($course, $cm, $context, $filearea, $args, $forcedownload, array $options = array())
{


	if ($context->contextlevel == CONTEXT_SYSTEM)
	{

	    $theme = theme_config::load('mb2aofk');


		switch ($filearea)
		{

			case 'logo' :
			return $theme->setting_file_serve('logo', $args, $forcedownload, $options);
			break;

			case 'logofooter' :
			return $theme->setting_file_serve('logofooter', $args, $forcedownload, $options);
			break;

			case 'bannerimg' :
			return $theme->setting_file_serve('bannerimg', $args, $forcedownload, $options);
			break;

			case 'pbgimage' :
			return $theme->setting_file_serve('pbgimage', $args, $forcedownload, $options);
			break;

			case 'bcbgimage' :
			return $theme->setting_file_serve('bcbgimage', $args, $forcedownload, $options);
			break;

			case 'acbgimage' :
			return $theme->setting_file_serve('acbgimage', $args, $forcedownload, $options);
			break;

			case 'asbgimage' :
			return $theme->setting_file_serve('asbgimage', $args, $forcedownload, $options);
			break;

			case 'loginbgimage' :
			return $theme->setting_file_serve('loginbgimage', $args, $forcedownload, $options);
			break;

			case 'loginlogo' :
			return $theme->setting_file_serve('loginlogo', $args, $forcedownload, $options);
			break;

			case 'loadinglogo' :
			return $theme->setting_file_serve('loadinglogo', $args, $forcedownload, $options);
			break;

			case 'favicon' :
			return $theme->setting_file_serve('favicon', $args, $forcedownload, $options);
			break;

			case 'cfontfiles1' :
			return $theme->setting_file_serve('cfontfiles1', $args, $forcedownload, $options);
			break;

			case 'cfontfiles2' :
			return $theme->setting_file_serve('cfontfiles2', $args, $forcedownload, $options);
			break;

			case 'cfontfiles3' :
			return $theme->setting_file_serve('cfontfiles3', $args, $forcedownload, $options);
			break;

			default :
			send_file_not_found();

		}

	}
	else
	{
        send_file_not_found();
    }

}







/*
 *
 * Method to get array of css classess
 *
 *
 */
function theme_mb2aofk_line_classes ($string, $id, $pref = '', $suff = '')
{



	$output = '';


	$blockStylesArr =  preg_split('/\r\n|\n|\r/', $string);



	if ($string !='')
	{

		foreach ($blockStylesArr as $line)
		{

			$lineArr = explode(':', $line);
			$prefArr = explode(',', $pref);

			if (trim($id) == trim($lineArr[0]))
			{
				$isPref1 = isset($prefArr[0]) ? $prefArr[0] : '';
				$output .= $prefArr[0] . $lineArr[1] . $suff;
			}

			if (isset($lineArr[2]))
			{
				if (trim($id) == trim($lineArr[0]))
				{
					$isPref2 = isset($prefArr[1]) ? $prefArr[1] : '';
					$output .= $isPref2 . $lineArr[2] . $suff;
				}
			}

		}

	}


	return $output;

}











/*
 *
 * Method to to get theme setting
 *
 *
 */
function theme_mb2aofk_theme_setting ($page, $name, $default = '', $image = false, $theme= false)
{


	if ($theme)
	{
		if (!empty($theme->settings->$name))
		{

			if ($image === true)
			{
				$output = $theme->setting_file_url($name, $name);
			}
			else
			{
				$output = $theme->settings->$name;
			}
		}
		else
		{
			$output = $default;
		}

	}
	else
	{
		if (!empty($page->theme->settings->$name))
		{

			if ($image === true)
			{
				$output = $page->theme->setting_file_url($name, $name);
			}
			else
			{
				$output = $page->theme->settings->$name;
			}
		}
		else
		{
			$output = $default;
		}
	}

	return $output;

}







/*
 *
 * Method to get langauge list
 *
 */
function theme_mb2aofk_language_list ()
{


	global $PAGE, $OUTPUT, $CFG;

	$moodle33 = 2017051500;
	$output = '';
	$langs = get_string_manager()->get_list_of_translations();
	$strlang =  get_string('language');
	$currentlang = current_language();


	$customFlagFile = $CFG->dirroot . '/theme/mb2aofk/pix/flags/custom/' . strtoupper($currentlang) . '.png';
	$flagFile = $CFG->dirroot . '/theme/mb2aofk/pix/flags/48x32/' . strtoupper($currentlang) . '.png';
	$noFlagFile = $CFG->dirroot . '/theme/mb2aofk/pix/flags/48x32/noflag.png';
	$isCustomFlag = file_exists($customFlagFile) ? true : false;
	$isFlag = file_exists($flagFile) ? true : false;


	if($isCustomFlag)
	{
		$currentFlagUrl = $CFG->version >= 	$moodle33 ? $OUTPUT->image_url('flags/custom/' . strtoupper($currentlang),'theme') : $OUTPUT->pix_url('flags/custom/' . strtoupper($currentlang),'theme');
	}
	elseif ($isFlag)
	{
		$currentFlagUrl = $CFG->version >= 	$moodle33 ? $OUTPUT->image_url('flags/48x32/' . strtoupper($currentlang),'theme') : $OUTPUT->pix_url('flags/48x32/' . strtoupper($currentlang),'theme');
	}
	else
	{
		$currentFlagUrl = $CFG->version >= 	$moodle33 ? $OUTPUT->image_url('flags/48x32/noflag','theme') : $OUTPUT->pix_url('flags/48x32/noflag','theme');
	}


	$langText = isset($langs[$currentlang]) ? $langs[$currentlang] : $strlang;
	$currentFlagImg = '<span class="lang-img" style="background-image:url(\'' . $currentFlagUrl . '\');"></span>';


	if (count($langs)>1)
	{

		$output .= '<li class="level-1 lang-item dropdown">';
		//$output .= '<a href="' . new moodle_url($PAGE->url, array('lang' => $currentlang)) . '" title="' . $langText . '">';
		$output .= '<a href="#">';
		//$output .= '<span class="lang-shortname">' . $currentlang . '</span>';
		// Set only lanuage text
		// preg_replace("/\(([^()]*+|(?R))*\)/","", $langText)
		$output .= '<span class="lang-fullname">' . $langText . '</span>';
		$output .= $currentFlagImg;
		$output .= '<span class="mobile-arrow"></span>';
		$output .= '</a>';
		$output .= '<ul class="dropdown-list">';



		foreach ($langs as $langtype => $langname)
		{

			if ($langtype)
			{

				$flagFile1 = $CFG->dirroot . '/theme/mb2aofk/pix/flags/custom/' . strtoupper($langtype) . '.png';
				$flagFile2 = $CFG->dirroot . '/theme/mb2aofk/pix/flags/48x32/' . strtoupper($langtype) . '.png';
				$isFlag1 = file_exists($flagFile1) ? true : false;
				$isFlag2 = file_exists($flagFile2) ? true : false;
				$active_cls = '';

				if ($langtype === $currentlang)
				{
					$active_cls = 'active';
				}


				if ($isFlag1)
				{
					$flagUrl = $CFG->version >= $moodle33 ? $OUTPUT->image_url('flags/custom/' . strtoupper($langtype),'theme') : $OUTPUT->pix_url('flags/custom/' . strtoupper($langtype),'theme');
				}
				elseif ($isFlag2)
				{
					$flagUrl = $CFG->version >= $moodle33 ? $OUTPUT->image_url('flags/48x32/' . strtoupper($langtype),'theme') : $OUTPUT->pix_url('flags/48x32/' . strtoupper($langtype),'theme');
				}
				else
				{
					$flagUrl = $CFG->version >= $moodle33 ? $OUTPUT->image_url('flags/48x32/noflag','theme') : $OUTPUT->pix_url('flags/48x32/noflag','theme');
				}

				$flafImg = '<span class="lang-img" style="background-image:url(\'' . $flagUrl . '\');"></span>';

				$output .= '<li class="' . $active_cls . '">';
				//$output .= '<a href="' . new moodle_url($PAGE->url, array('lang' => $langtype)) . '" title="' . $langname . '">';
				$output .= '<a href="' . new moodle_url($PAGE->url, array('lang' => $langtype)) . '">';

				$output .= '<span class="lang-shortname">' . $langtype . '</span>';
				$output .= '<span class="lang-fullname">' . $langname . '</span>';
				$output .= $flafImg;
				$output .= '</a>';
				$output .= '</li>';

			}

		}


		$output .= '</ul>';
		$output .= '</li>';

	}


	return $output;

}





/*
 *
 * Method to get langauge list
 *
 *
 */
function theme_mb2aofk_mycourses_list()
{

	global $PAGE;
	$output = '';
	$courses = theme_mb2aofk_get_mycourses();
	$limit = theme_mb2aofk_theme_setting($PAGE, 'mcnamelimit', 6);

	if (!count($courses))
	{
		return;
	}

	$output .= '<li class="level-1 mycourses dropdown">';

	$output .= '<a href="#" title="' . get_string('mycourses') . '">';
	$output .= get_string('mycourses') . ' <span class="mycourses-num">(' . count($courses) . ')</span>';
	$output .= '<span class="mobile-arrow"></span>';
	$output .= '</a>';

	$output .= '<ul class="dropdown-list">';

	foreach ($courses as $c)
	{
		$course_url = new moodle_url('/course/view.php?id=' . $c['id']);
		$coursename = strip_tags(format_text($c['fullname']));

		$output .= '<li class="visible' . $c['visible'] . ' ' . $c['roles'] . '">';
		$output .= '<a href="' . $course_url . '" title="' . $coursename . '">';
		$output .= theme_mb2aofk_wordlimit($coursename, $limit);
		$output .= '</a>';
		$output .= '</li>';
	}

	$output .= '</ul>';
	$output .= '</li>';

	return $output;

}







/*
 *
 * Method to check if is my course list
 *
 */
function theme_mb2aofk_get_mycourses ()
{
	global $USER;

	$my_courses = enrol_get_my_courses();
	$courses = array();

	foreach ( $my_courses as $c )
	{
		$course_access = theme_mb2aofk_site_access($c->id);

		if ( ! $c->visible && ! in_array( $course_access, array('admin', 'manager', 'editingteacher') ) )
		{
			continue;
		}

		$courses[] = array( 'id' => $c->id, 'fullname' => $c->fullname, 'visible' => $c->visible,
		'roles' => implode(' ', theme_mb2aofk_get_user_course_roles($c->id, $USER->id) ) );

	}



	return $courses;

}




/*
 *
 * Method to get safe url string
 *
 */
function theme_mb2aofk_string_url_safe($string)
{

	// Remove any '-' from the string since they will be used as concatenaters
	$output = str_replace('-', ' ', $string);


	// Trim white spaces at beginning and end of alias and make lowercase
	$output = trim(mb_strtolower($output));


	// Remove any duplicate whitespace, and ensure all characters are alphanumeric
	//$output = preg_replace('/(\s|[^A-Za-z0-9\-])+/', '-', $output);
   $output = preg_replace('#[^\w\d_\-\.]#iu', '-', $output);


	// Trim dashes at beginning and end of alias
	$output = trim($output, '-');


	return $output;

}






/*
 *
 * Method to get logo url
 *
 *
 */
function theme_mb2aofk_logo_url($page, $customLogo = '', $login = true)
{

	global $OUTPUT, $CFG;
	$moodle33 = 2017051500;

	// Url to default logo image
	$defaultLogo = $CFG->version >= $moodle33 ? $OUTPUT->image_url('logo-default','theme') : $OUTPUT->pix_url('logo-default','theme');

	// Check if is custom login page
	$customLoginPage = theme_mb2aofk_is_login($page, true);

	if ($login && $customLoginPage && theme_mb2aofk_theme_setting($page,'loginlogo','', true) )
	{
		$isCustomLogo = theme_mb2aofk_theme_setting($page,'loginlogo','', true);
	}
	else
	{
		$isCustomLogo = $customLogo !='' ? $customLogo : theme_mb2aofk_theme_setting($page,'logo','', true);
	}

	$logoUrl = $isCustomLogo !='' ? $isCustomLogo : $defaultLogo;

	return $logoUrl;

}




/*
 *
 * Method to get page background image
 *
 *
 */
function theme_mb2aofk_pagebg_image($page)
{

	global $OUTPUT, $CFG;
	$moodle33 = 2017051500;
	$pageBgUrl = '';


	// Url to page background image
	$pageBgDef = $CFG->version >= $moodle33 ? $OUTPUT->image_url('pagebg/default','theme') : $OUTPUT->pix_url('pagebg/default','theme');
	$pageBgLoginDef = $CFG->version >= $moodle33 ? $OUTPUT->image_url('pagebg/default-login','theme') : $OUTPUT->pix_url('pagebg/default-login','theme');
	$pageBg = theme_mb2aofk_theme_setting($page, 'pbgimage', '', true);
	$pageBgPre = theme_mb2aofk_theme_setting($page, 'pbgpre', '');
	$pageBgLogin = theme_mb2aofk_theme_setting($page, 'loginbgimage', '', true);
	$pageBgLoginPre = theme_mb2aofk_theme_setting($page, 'loginbgpre', '');


	// Check if is custom login page
	$customLoginPage = theme_mb2aofk_is_login($page, true);


	if ($customLoginPage && ($pageBgLogin || $pageBgLoginPre === 'default'))
	{
		if ($pageBgLogin)
		{
			$pageBgUrl = $pageBgLogin;
		}
		elseif ($pageBgLoginPre === 'default')
		{
			$pageBgUrl = $pageBgLoginDef;
		}
	}
	elseif ($pageBg)
	{
		$pageBgUrl = $pageBg;
	}
	elseif ($pageBgPre === 'default')
	{
		$pageBgUrl = $pageBgDef;
	}


	return $pageBgUrl !='' ? ' style="background-image:url(\'' . $pageBgUrl . '\');"' : '';


}






/*
 *
 * Method to get loading screen
 *
 *
 */
function theme_mb2aofk_loading_screen($page)
{

	global $OUTPUT, $SITE;


	$output = '';


	$isBgColor = theme_mb2aofk_theme_setting($page,'lbgcolor','') !='' ? ' style="background-color:' . theme_mb2aofk_theme_setting($page,'lbgcolor','') . ';"' : '';

	if (!is_siteadmin())
	{
		$logow = theme_mb2aofk_theme_setting($page,'loadinglogow') != '' ? theme_mb2aofk_theme_setting($page,'loadinglogow') : theme_mb2aofk_theme_setting($page,'logow',200);

		$output .= '<div class="loading-scr" data-hideafter="' . theme_mb2aofk_theme_setting($page, 'loadinghide',600) . '"' . $isBgColor . '>';
		$output .= '<div class="loading-scr-inner" style="width:' . $logow . 'px;max-width:100%;margin-left:-' . round($logow/2) . 'px;">';
		$output .= '<img class="loading-scr-logo" src="' . theme_mb2aofk_logo_url($page, theme_mb2aofk_theme_setting($page,'loadinglogo','', true), false) . '" alt="' . $SITE->shortname . '">';
		$output .= '<div class="loading-scr-spinner"><img src="' . theme_mb2aofk_loading_spinner() . '" alt="' . get_string('loading','theme_mb2aofk') . '" style="width:' . theme_mb2aofk_theme_setting($page, 'spinnerw', 35) . 'px;"></div>';
		$output .= '</div>';
		$output .= '</div>';


	}


	return $output;


}





/*
 *
 * Method to get spinner svg image
 *
 *
 */
function theme_mb2aofk_loading_spinner ()
{

	global $CFG;
	$output = '';


	$spinnerDir = $CFG->dirroot . '/theme/mb2aofk/pix/spinners/';
	$spinnerCustomDir = $CFG->dirroot . '/theme/mb2aofk/pix/spinners/custom';


	$spinner = theme_mb2aofk_random_image($spinnerDir, 'spinners', array('gif','svg'));
	$spinnerCustom = theme_mb2aofk_random_image($spinnerCustomDir, 'spinners/custom', array('gif','svg'));


	$output = $spinnerCustom ? $spinnerCustom : $spinner;


	return $output;

}






/*
 *
 * Method to get loading screen
 *
 */
function theme_mb2aofk_scrolltt($page)
{

	global $OUTPUT, $SITE;

	$output = '';

	$output .= '<a class="theme-scrolltt" href="#" data-toggle="tooltip" data-trigger="hover" title="' . get_string('scrolltotop', 'theme_mb2aofk') . '"><span><i class="fa fa-angle-up" data-scrollspeed="' .
	theme_mb2aofk_theme_setting($page, 'scrollspeed',400) . '"></i></span></a>';

	return $output;

}








/*
 *
 * Method to get icon navigation
 *
 *
 */
function theme_mb2aofk_iconnav($page)
{

	$iconnavs = theme_mb2aofk_theme_setting($page, 'navicons');

	if ($iconnavs !='')
	{
		return theme_mb2aofk_static_content($iconnavs, true, array('listcls'=>'theme-iconnav'));
	}

}




/*
 *
 * Method to get Gogole Analytics code
 *
 *
 */
function theme_mb2aofk_ganalytics($page, $type = 1)
{

	$output = '';
	$codeId = theme_mb2aofk_theme_setting($page, 'ganaid');
	$codeAsync = theme_mb2aofk_theme_setting($page, 'ganaasync', 0);


	if ($codeId !='')
	{
		//Alternative async tracking snippet
		if($codeAsync == 1)
		{
			$output .= '<script>';
			$output .= 'window.ga=window.ga||function(){(ga.q=ga.q||[]).push(arguments)};ga.l=+new Date;';
			$output .= 'ga(\'create\', \'' . $codeId . '\', \'auto\');';
			$output .= 'ga(\'send\', \'pageview\');';
			$output .= '</script>';
			$output .= '<script async src=\'https://www.google-analytics.com/analytics.js\'></script>';
		}
		else
		{
			$output .= '<script>';
			$output .= '(function(i,s,o,g,r,a,m){i[\'GoogleAnalyticsObject\']=r;i[r]=i[r]||function(){';
			$output .= '(i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),';
			$output .= 'm=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)';
			$output .= '})(window,document,\'script\',\'https://www.google-analytics.com/analytics.js\',\'ga\');';
			$output .= 'ga(\'create\', \'' . $codeId . '\', \'auto\');';
			$output .= 'ga(\'send\', \'pageview\');';
			$output .= '</script>';
			$output .= '';
		}
	}


	return $output;


}






/*
 *
 * Method to get favicon
 *
 *
 */
function theme_mb2aofk_favicon ($page)
{

	global $OUTPUT, $CFG;


	$output = '';
	$moodle33 = ($CFG->version >= 2017051500);
	$favImg = $CFG->dirroot . '/theme/mb2aofk/pix/favicon/favicon-16x16.ico';


	// Additional favicons
	$favDeskDir = $CFG->dirroot . '/theme/mb2aofk/pix/favicon/desktop/';
	$favMobDir = $CFG->dirroot . '/theme/mb2aofk/pix/favicon/mobile/';
	$deskIcons = theme_mb2aofk_file_arr($favDeskDir, array('png'));
	$mobIcons = theme_mb2aofk_file_arr($favMobDir, array('png'));


	return $output;

}



















/*
 *
 * Method to display sho/hide sidebar button
 *
 *
 */
function theme_mb2aofk_show_hide_sidebars ($page, $vars = array())
{

	$output = '';

	$sidebarBtn = theme_mb2aofk_theme_setting($page,'sidebarbtn');
	$showSdebar = ($sidebarBtn == 1 || $sidebarBtn == 2);


	if (isset($vars['sidebar']) && $vars['sidebar'] && $showSdebar)
	{

		$output .= '<a href="#" class="theme-hide-sidebar mode' . $sidebarBtn . '" data-showtext="' . get_string('showsidebar','theme_mb2aofk') . '" data-hidetext="' .
		get_string('hidesidebar','theme_mb2aofk') . '">';
		$output .= $sidebarBtn == 2 ? get_string('showsidebar','theme_mb2aofk') : get_string('hidesidebar','theme_mb2aofk');
		$output .= '</a>';

	}


	return $output;

}








/*
 *
 * Method to add body class to idetntify moodle version in js files
 *
 *
 */
function theme_mb2aofk_midentify ($vars = array())
{

	global $CFG;
	$output = '';

	$m38Cls = 'custom_id_5e37f615d176';
	$m38 = $CFG->version >= 2019111800;

	// Check if is Moodle 3.8
	if ( $m38 )
	{
		$output .= ' ' . $m38Cls;
	}

	return $output;

}






/*
 *
 * Method to get all plugins array
 *
 *
 */
function theme_mb2aofk_plugins_arr()
{

	global $CFG;

	$output = array(
		//'mb2slider'=>array('text'=>get_string('mb2slider_plugin','theme_mb2aofk'),'file'=>$CFG->dirroot . '/blocks/mb2slider/block_mb2slider.php'),
		'mb2shortcodes_filter'=>array('text'=>get_string('mb2shortcodes_filter_plugin','theme_mb2aofk'),'file'=>$CFG->dirroot . '/filter/mb2shortcodes/filter.php'),
		//'mb2shortcodes_button'=>array('text'=>get_string('mb2shortcodes_button_plugin','theme_mb2aofk'),'file'=>$CFG->dirroot . '/lib/editor/atto/plugins/mb2shortcodes/ajax.php')
	);

	return $output;

}





/*
 *
 * Method to check if plugins are installed
 *
 */
 function theme_mb2aofk_check_plugins()
 {

 	$output = '';
 	$plugins = theme_mb2aofk_plugins_arr();
 	$show_alert = 0;

 	foreach ($plugins as $id=>$plugin)
 	{
 		$show_alert = !file_exists($plugin['file']);

 		if ($id === 'mb2shortcodes_filter')
 		{
 			$show_alert = !theme_mb2aofk_check_shortcodes_filter();
 		}

 		if ($show_alert)
 		{
 			$output .= '<div class="alert alert-warning" role="alert">' . $plugin['text'] . '</div>';
 		}
 	}

 	return $output;

 }






/*
 *
 * Method to get shot text from string
 *
 *
 */
function theme_mb2aofk_wordlimit($string, $limit = 999, $end = '...')
{

	$output = $string;

	if ( $limit >= 999 )
	{
		return $output;
	}

	$content_limit = strip_tags( $string );
	$words = explode( ' ', $content_limit );
	$words_count = count( $words );
	$new_string = implode( ' ', array_splice( $words, 0, $limit ) );
	$end_char = ( $end !== '' && $words_count > $limit ) ? $end : '';
	$output = $new_string . $end_char;

	return $output;

}





/*
 *
 * Method to check moodle version
 *
 */
function theme_mb2aofk_moodle_from ($version)
{

	global $CFG;

	if ( $CFG->version >= $version )
	{
		return true;
	}

	return false;

}




/*
 *
 * Method to check if user has role
 *
 */
function theme_mb2aofk_is_user_role($courseid, $roleid, $userid = 0)
{

	 $roles = get_user_roles(context_course::instance($courseid), $userid, false);

	 foreach ($roles as $role)
	 {
		  if ($role->roleid == $roleid)
		  {
			  return true;
		  }
	 }

    return false;
}






/*
 *
 * Method to add font icon class prefix
 *
 */
function theme_mb2aofk_font_icon_prefix($icon)
{

	$output = '';

	$isfa = (preg_match('@fa-@', $icon) && !preg_match('@fa fa-@', $icon));
	$isglyph = (preg_match('@glyphicon-@', $icon) && !preg_match('@glyphicon glyphicon-@', $icon));

	if ($isfa)
	{
	   $output = 'fa ';
	}
	elseif ($isglyph)
	{
	   $output = 'glyphicon ';
	}

    return $output;

}





/*
 *
 * Method to set body class for course category theme
 *
 */
function theme_mb2aofk_page_title($coursename = true)
{

	global $PAGE, $COURSE;

	$title = '';
	$page_title = strip_tags( format_text( $PAGE->title ) );

	$itle_arr = explode(':', $page_title);

	if ($coursename && $COURSE->id > 1 && !preg_match('@course-view@', $PAGE->pagetype))
	{
		$title .= strip_tags( format_text( $COURSE->fullname ) ) . ': ';
	}

	$title .= end($itle_arr);

	return $title;

}




/*
 *
 * Method to get content from lines
 *
 */
function theme_mb2aofk_line_content($text)
{

	$output = '';
	$line = array();
	$content = array();
	$i = 0;

	// Explode new line
	$line_arr = preg_split('/\r\n|\n|\r/', trim($text));

	foreach ($line_arr as $line)
	{

		$i++;
		$line_arr = explode('|', trim($line));
		$line1 = $line_arr[0]; // Name and icon
		$line2 = isset($line_arr[1]) ? $line_arr[1] : ''; // Link and target attribute
		$line3 = isset($line_arr[2]) ? $line_arr[2] : ''; // Language codes
		$line4 = isset($line_arr[3]) ? $line_arr[3] : ''; // Logged in or none logged in users

		// Get sub array from line
		$text_arr = explode('::', trim($line1));
		$url_arr = explode('::', trim($line2));
		$lang_arr = $line3 ? explode(',', trim($line3)) : array();


		$content[$i]['text'] = trim($text_arr[0]);
		$content[$i]['icon'] = isset($text_arr[1]) ? trim($text_arr[1]) : '';
		$content[$i]['url'] = isset($url_arr[0]) ? trim($url_arr[0]) : '';
		$content[$i]['url_target'] = isset($url_arr[1]) ? trim($url_arr[1]) : 0;
		$content[$i]['lang'] = $lang_arr;
		$content[$i]['logged'] = trim($line4);

	}

	return $content;

}




/*
 *
 * Method to get static content top and bottom
 *
 */
function theme_mb2aofk_static_content($text, $list = true, $options = array())
{

	$output = '';
	$i = 0;
	$content = theme_mb2aofk_line_content($text);
	$style = '';
	$listcls = '';

	if (isset($options['mt']))
	{
		$style = ' style="margin-top:' . trim($options['mt']) . 'px;"';
	}

	if (isset($options['listcls']))
	{
		$listcls = ' ' . $options['listcls'];
	}

	$output .= $list ? '<ul class="theme-static-content' . $listcls . '"' . $style . '>' : '';

	foreach ($content as $item)
	{

		$target = '';
		$icon_pref = '';

		// Check language
		if (count($item['lang']) > 0 && !in_array(current_language(), $item['lang']))
		{
			continue;
		}

		// Check logged
		if ($item['logged'] == 1 || $item['logged'] == 2)
		{
			// Content for logged in users only
			if ($item['logged'] == 1 && (!isloggedin() || isguestuser()))
			{
				continue;
			}
			// Content for none logged in users and gusets only
			elseif ($item['logged'] == 2 && (isloggedin() && !isguestuser()))
			{
				continue;
			}
		}

		$i++;

		$output .= '<li class="theme-static-item' . $i . '">';

		if ($item['url'] && $item['url_target'])
		{
			$target = ' target="_blank"';
		}

		if ($item['icon'])
		{
			$icon_pref = theme_mb2aofk_font_icon_prefix($item['icon']);
		}

		$output .= $item['url'] ? '<a class="link-replace" href="' . $item['url'] . '"' . $target . '>' : '<span class="link-replace">';
		$output .= $item['icon'] ? '<span class="static-icon"><i class="' . $icon_pref . $item['icon'] . '"></i></span>' : '';
		$output .= '<span class="text">' . $item['text'] . '</span>';
		$output .= $item['url'] ? '</a>' : '</span>';
		$output .= '</li>';

	}

	$output .= $list ? '</ul>' : '';

	return $output;

}




/*
 *
 * Method to get static content top and bottom
 *
 */
function theme_mb2aofk_check_for_tags ($string, $tags = 'p|span|b|strong|i|u')
{

	$pattern = "/<($tags) ?.*>(.*)<\/($tags)>/";
	preg_match($pattern, $string, $matches);

	if (!empty($matches))
	{
	    return true;
	}

	return false;
}



/*
 *
 * Method to set course layout body class
 *
 */
function theme_mb2aofk_course_layout_class()
{

	global $PAGE;
	$output = '';
	$is_course_cat = ($PAGE->pagetype === 'course-index-category' && theme_mb2aofk_theme_setting($PAGE, 'coursegridcat'));
	$is_course_fp = ($PAGE->pagetype === 'site-index' && theme_mb2aofk_theme_setting($PAGE, 'coursegridfp'));

	if ($is_course_cat || $is_course_fp)
	{
		return 'course-layout-grid';
	}

	return ;

}



/*
 *
 * Method to get course categor layout switcher
 *
 */
function theme_mb2aofk_course_layout_switcher()
{
	global $PAGE;
	$output = '';
	$is_course_cat = ($PAGE->pagetype === 'course-index-category' && theme_mb2aofk_theme_setting($PAGE, 'coursegridcat'));
	$is_course_fp = ($PAGE->pagetype === 'site-index' && theme_mb2aofk_theme_setting($PAGE, 'coursegridfp'));
	$actice_cls_grid = '';
	$actice_cls_list = ' active';

	if ($is_course_cat || $is_course_fp)
	{
		$actice_cls_grid = ' active';
		$actice_cls_list = '';
	}

	$output .= '<div class="course-layout-switcher">';
	$output .= '<a href="#" class="grid-layout' . $actice_cls_grid . '" title="' .
	get_string('layoutgrid', 'theme_mb2aofk') . '" data-toggle="tooltip" data-trigger="hover"><i class="fa fa-th-large"></i></a>';
	$output .= '<a href="#" class="list-layout' . $actice_cls_list . '" title="' .
	get_string('layoutlist', 'theme_mb2aofk') . '" data-toggle="tooltip" data-trigger="hover"><i class="fa fa-th-list"></i></a>';
	$output .= '</div>';

	return $output;

}


/*
 *
 * Method to check for front page courses
 *
 */
function theme_mb2aofk_frontpage_courses()
{

	global $CFG;

	$loggedin_arr = explode(',', $CFG->frontpageloggedin);
	$noneloggedin_arr = explode(',', $CFG->frontpage);

	if (isloggedin() && !isguestuser())
	{
		if (in_array(6, $loggedin_arr))
		{
			return true;
		}
	}
	else
	{
		if (in_array(6, $noneloggedin_arr))
		{
			return true;
		}
	}

	return false;

}




/*
 *
 * Method to check if shortcodes filter is activated
 *
 */
function theme_mb2aofk_check_shortcodes_filter()
{
	global $DB;
	$filters = array();

	// Get array of active filters
	$dbfilters = $DB->get_records('filter_active', array('active'=>1), '', 'filter');

	foreach ( $dbfilters as $f )
	{
		if ( isset( $f->filter ) )
		{
			$filters[] = $f->filter;
		}
	}

	if ( in_array( 'mb2shortcodes', $filters ) )
	{
		return true;
	}

	return false;

}






/*
 *
 * Method to get param value from url
 *
 */
function theme_mb2aofk_get_url_param ($url, $param = 'id')
{
	$parts = parse_url($url);
	parse_str($parts['query'], $query);

	if (isset($query[$param]))
	{
		return $query[$param];
	}

	return null;

}



/*
 *
 * Method to get user details by user id
 *
 */
function theme_mb2aofk_get_user_details ($id, $detail = 1, $options = array('size'=>148))
{
	global $OUTPUT, $DB, $USER;

	if (!$id)
	{
		$id = $USER->id;
	}

	$user = $DB->get_record('user', array('id'=>$id));

	if ($detail == 1)
	{
		return $OUTPUT->user_picture($user, $options);
	}
	elseif ($detail == 2)
	{
		return $user->firstname . ' ' . $user->lastname;
	}

}





/*
 *
 * Method to check if is course module context
 *
 */
function theme_mb2aofk_is_module_context()
{

	global $PAGE;

	$context = $PAGE->context;

	if ($context->contextlevel == CONTEXT_MODULE)
	{
		return true;
	}

	return false;

}




/*
 *
 * Method to get user role name
 *
 */
function theme_mb2aofk_get_role()
{
	global $DB, $USER;
	$user_roles = array();
	$pref = 'rolename-';
	$roles = get_all_roles();

	if ( ! $roles )
	{
		return ;
	}

	foreach ( $roles as $role )
	{
		if ( user_has_role_assignment( $USER->id, $role->id ) )
		{
			$user_roles[] = $pref . $role->shortname;
		}
	}

	if ( count( $user_roles ) == 0 )
	{
		return ;
	}

	return $user_roles;

}




/*
 *
 * Method to get user roles
 *
 */
function theme_mb2aofk_get_user_roles( $userid = null )
{
	global $DB;
	$roles = array();

	if ( ! $userid )
	{
		return $roles;
	}

	$roles = $DB->get_records_list('role_assignments', 'userid', array('userid' => $userid ), '', 'id,contextid,roleid');

	return $roles;

}





/*
 *
 * Method to get user roles
 *
 */
function theme_mb2aofk_get_user_course_roles( $courseid = null, $userid = null )
{
	global $DB;
	$courseroles = array();

	if ( ! $userid || ! $courseid )
	{
		return array();
	}

	$context = context_course::instance( $courseid );
	$userroles = theme_mb2aofk_get_user_roles( $userid );

	foreach ( $userroles as $userrole )
	{
		if ( $context->id == $userrole->contextid )
		{
			$courseroles[] = theme_mb2aofk_get_role_shortname( $userrole->roleid );
		}
	}

	return $courseroles;

}





/*
 *
 * Method to get user role shortname
 *
 */
function theme_mb2aofk_get_role_shortname( $roleid = null )
{

	if ( ! $roleid )
	{
		return ;
	}

	$roles = get_all_roles();

	foreach ( $roles as $role )
	{
		if ( $roleid == $role->id )
		{
			return $role->shortname;
		}
	}

}




/*
 *
 * Method to get header actions
 *
 */
function theme_mb2aofk_header_actions()
{
	global $PAGE;

	$output = '';

	if ( ! theme_mb2aofk_moodle_from( 2020110900 ) )
	{
		return;
	}

	foreach ( $PAGE->get_header_actions() as $a )
	{
		$output .= $a;
	}

	return $output;

}




/*
 *
 * Method to get files from filearea
 *
 */
function theme_mb2aofk_filearea( $filearea = '', $image = true )
{

	if ( ! $filearea )
	{
		return;
	}

	$context = context_system::instance();
	$url = '';
	$urls = array();
	$i = 0;
	$fs = get_file_storage();
	$files = $fs->get_area_files($context->id, 'theme_mb2aofk', $filearea );

	foreach ($files as $f)
	{
		$checkimage = $image ? $f->is_valid_image() : $f->get_filename() !== '.';

		if ( $checkimage )
		{
			$i++;
			$sep = $i > 1 ? ',' : '';
			$url .= $sep . moodle_url::make_pluginfile_url($f->get_contextid(), $f->get_component(), $f->get_filearea(), $f->get_itemid(), $f->get_filepath(), $f->get_filename());
		}
	 }

	 $urls = explode( ',', $url );
	 $urls = array_filter($urls);

	 return $urls;

}
