<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 *
 * @package   theme_mb2aofk
 * @copyright 2019 - 2020 Mariusz Boloz (https://mb2themes.com)
 * @license   Commercial https://themeforest.net/licenses
 *
 */



defined('MOODLE_INTERNAL') || die();



/*
 *
 * Method to get search form
 *
 */
function theme_mb2aofk_panel_links()
{

    global $PAGE, $OUTPUT, $USER, $CFG;

    $output = '';
    $isLoginPage = theme_mb2aofk_is_login($PAGE);
    $loginicon = (!isloggedin() or isguestuser()) ? 'fa fa-lock' : 'fa fa-user';
    $loginstring = (!isloggedin() or isguestuser())? get_string('login') :  $USER->firstname . ' <span>' . $USER->lastname . '</span>';
    $modalattr = ' data-toggle="modal" data-target="#header-login"';


    if (theme_mb2aofk_theme_setting($PAGE,'navbarplugin') && theme_mb2aofk_moodle_from(2016120500))
    {
        $output .= '<div class="theme-plugins">';
        $output .= $OUTPUT->navbar_plugin_output();
        $output .= '</div>';
    }

    $output .= '<a href="#" data-toggle="modal" data-target="#header-search" class="search-btn btn isicon" title="' . get_string('search','core') . '">';
    $output .= '<span class="btn-icon"><i class="fa fa-search"></i></span>';
    $output .= '<span class="text1">' . get_string('search','core') . '</span>';
    $output .= '</a>';

    if ( ! $isLoginPage )
    {
        $link_to_login = theme_mb2aofk_theme_setting( $PAGE, 'loginlinktopage' );
		$login_link = '#';

        if ( ( ! isloggedin() || isguestuser() ) && $link_to_login )
        {
            $modalattr = '';

            if ( $CFG->alternateloginurl )
            {
                $login_link = $CFG->alternateloginurl;
            }
            else
            {
                $login_link = new moodle_url( $CFG->wwwroot . '/login/index.php', array() );
            }
        }

        $output .= '<a href="' . $login_link . '"' . $modalattr . ' class="login-btn btn btn-primary isicon" title="' . $loginstring . '">';
        $output .= '<span class="btn-icon"><i class="' . $loginicon . '"></i></span>';
        $output .= '<span class="text1">' . $loginstring . '</span>';
        $output .= '</a>';
    }


    if (is_siteadmin())
    {
        $output .= '<a href="#" class="settings-btn btn btn-warning isicon" data-toggle="modal" data-target="#header-theme-settings" title="' . get_string('themesettings','admin') . '">';
        $output .= '<span class="btn-icon"><i class="fa fa-sliders"></i></span>';
        $output .= '<span class="text1">' . get_string( 'settings' ) . '</span>';
        $output .= '</a>';
    }

    return $output;


}




/*
 *
 * Method to get search form
 *
 */
function theme_mb2aofk_search_form()
{
	global $CFG, $PAGE;

	$output = '';
    $cls = ' noglobalsearch';
    $search_action = new moodle_url($CFG->wwwroot . '/course/search.php',array());
    $search_action_global = new moodle_url($CFG->wwwroot . '/search/index.php',array());
	$search_text = get_string('searchcourses');
    $search_menu_items = theme_mb2aofk_theme_setting($PAGE,'searchlinks');
    $global_search = ( $CFG->enableglobalsearch && theme_mb2aofk_moodle_from(2016052300) );

    if ( $global_search )
    {
        $cls = ' isglobalsearch';
    }

	$output .= '<div class="theme-searchform' . $cls . '" data-action_global="' . $search_action_global . '" data-action_course="' . $search_action . '">';
	$output .= '<form id="theme-search" action="' . new moodle_url($CFG->wwwroot . '/course/search.php') . '" method="get">';
	$output .= '<input id="theme-coursesearchbox" type="text" value="" placeholder="' . get_string('enteryoursearchquery','search') . '" name="search">';

    if ( $global_search )
    {
        $output .= '<span class="switch custom-switch">';
        $output .= '<input type="checkbox" name="theme-search-checkbox" class="custom-control-input" id="theme-search-checkbox" data-name="theme-search-checkbox">';
        $output .= '<label for="theme-search-checkbox" class="custom-control-label" data-globalstring="' . get_string('globalsearch','admin') .
        '" data-coursesstring="' . get_string('searchcourses','core') . '">' . get_string('searchcourses','core') . '</label>';
        $output .= '</span>';
    }

	$output .= '<button type="submit"><i class="fa fa-search"></i></button>';
	$output .= '</form>';

    $output .= '</div>';

    $output .= '<div class="theme-searchlinks">';
    $output .= theme_mb2aofk_custom_links($search_menu_items, 'searchform', get_string('popularlinks','theme_mb2aofk'));
    $output .= '</div>';

	return $output;
}




/*
 *
 * Method to get moadl window with search form
 *
 */
function theme_mb2aofk_search_form_modal()
{
    global $PAGE;
    $output = '';
    $cls = '';

    $output .= '<div id="header-search" class="modal fade' . $cls . '" role="dialog">';
    $output .= '<div class="modal-dialog" role="document">';
    $output .= '<div class="modal-content">';
    $output .= '<div class="theme-modal-container">';
    $output .= '<a class="close-container" href="#" data-dismiss="modal">&times;</a>';
    $output .= theme_mb2aofk_search_form();
    $output .= '</div>';
    $output .= '</div>';
    $output .= '</div>';
    $output .= '</div>';


    return $output;

}



/*
 *
 * Method to get moadl window with theme settings links
 *
 */
function theme_mb2aofk_theme_links_modal ()
{
    global $CFG, $PAGE, $USER;
    $output = '';
    $cls = '';
    $purgelink = new moodle_url($CFG->wwwroot . '/admin/purgecaches.php', array('confirm'=>1, 'sesskey'=>$USER->sesskey, 'returnurl'=>$PAGE->url->out_as_local_url()));

    $output .= '<div id="header-theme-settings" class="modal modal-dark fade' . $cls . '" role="dialog">';
    $output .= '<div class="modal-dialog" role="document">';
    $output .= '<div class="modal-content">';
    $output .= '<div class="modal-header">';
    $output .= '<button type="button" class="close" data-dismiss="modal">&times;</button>';
    $output .= '<h4 class="modal-title">' . get_string( 'settings' ) . '</h4>';
    $output .= '</div>';
    $output .= '<div class="modal-body">';
    $output .= theme_mb2aofk_theme_links();
    $output .= '</div>';
    $output .= '<div class="modal-footer">';
    $docUrl = get_string('urldoc','theme_mb2aofk');
	$moreUrl = get_string('urlmore','theme_mb2aofk');
	$output .= '<a href="' . $purgelink . '" class="btn btn-warning btn-sm">' . get_string('purgecaches','admin') . '</a>';
	$output .= '<a href="' . $docUrl . '"  target="_blank" class="btn btn-info btn-sm">' . get_string('documentation','theme_mb2aofk') . '</a>';
	$output .= '<a href="' . $moreUrl . '" target="_blank" class="btn btn-success btn-sm">' . get_string('morethemes','theme_mb2aofk') . '</a>';
    $output .= '</div>';
    $output .= '</div>';
    $output .= '</div>';
    $output .= '</div>';

    return $output;

}





/*
 *
 * Method to get custom menu links
 *
 */
function theme_mb2aofk_custom_links($items, $id, $first = false)
{

	global $PAGE;
	$output = '';

	if ($items)
	{

		$search_links = new custom_menu($items, current_language());

		$output .= '<ul class="theme-' . $id . '-links">';
		$output .= $first ? '<li><span class="strong">' .  $first . '</span></li>' : '';

		foreach ($search_links->get_children() as $link)
		{

			$url = $link->get_url();

            $is_text = $link->get_text();
            $tetx_title = $is_text;

            if (preg_match('@::@', $is_text))
            {
                $is_text_arr = explode('::', $is_text);

                $icon_pref = theme_mb2aofk_font_icon_prefix($is_text_arr[1]);
                $icon = '<i class="' . $icon_pref . $is_text_arr[1] . '"></i>';
                $is_text = $icon . '<span class="text">' . $is_text_arr[0] . '</span>';
                $tetx_title = $is_text_arr[0];
            }

			$output .= '<li>';
			$output .= $url ? '<a href="' . $url . '">' : '';
			$output .= $is_text;
			$output .= $url ? '</a>' : '';
			$output .= '</li>';

		}

		$output .= '</ul>';

	}

	return $output;

}






/*
 *
 * Method to theme links
 *
 */
function theme_mb2aofk_theme_links()
{

	global $CFG, $USER, $PAGE;

	$output = '';
	$settings = theme_mb2aofk_settings_arr();
	$themename = theme_mb2aofk_themename();

	$output .= '<div class="theme-links">';
	$output .= '<ul>';

	foreach ($settings as $id=>$v)
	{
        $url = $v['url'] ? $v['url'] : new moodle_url($CFG->wwwroot . '/admin/settings.php', array('section'=>'theme_' . $themename . '_settings' . $id));

		$output .= '<li class="item-' . $id . '">';
		$output .= '<a href="' . $url . '">';
		$output .= '<i class="' . $v['icon'] . '"></i> ';
		$output .= $v['name'];
		$output .= '</a>';
		$output .= '</li>';
	}

	$output .= '</ul>';
	$output .= '</div>';

	return $output;

}






/*
 *
 * Method to get login form
 *
 */
function theme_mb2aofk_login_form()
{

	global $PAGE, $OUTPUT, $USER, $CFG;

	$output = '';
    $logintoken = '';
	$login_url = get_login_url();
    $link_to_login = theme_mb2aofk_theme_setting($PAGE, 'loginlinktopage');
    $loginlinks = theme_mb2aofk_theme_setting($PAGE, 'loginlinks');
    $onlyloginsocial = theme_mb2aofk_theme_setting($PAGE, 'onlyloginsocial');

    if (theme_mb2aofk_moodle_from(2017111300) && method_exists('\core\session\manager','get_login_token'))
    {
        $logintoken = '<input type="hidden" name="logintoken" value="' . s(\core\session\manager::get_login_token()) .'" />';
    }

	$output .= '<div class="theme-loginform">';

	if ( ( ! isloggedin() || isguestuser() ) && ! $link_to_login )
	{

        if ( $loginlinks )
        {
            $output .= '<div class="row">';
            $output .= '<div class="col-md-6 order-2 col-loginform">';
            $output .= '<div class="col-inner">';
        }

        $output .= $OUTPUT->theme_part('logo');

        if ( $onlyloginsocial != 1 )
        {
            $output .= '<form id="header-form-login" method="post" action="' . $login_url. '">';
    		$output .= '<div class="form-field">';
    		$output .= '<label id="user"><i class="fa fa-user"></i></label>';
    		$output .= '<input id="login-username" type="text" name="username" placeholder="' . get_string('username') . '" />';
    		$output .= '</div>';
    		$output .= '<div class="form-field">';
    		$output .= '<label id="pass"><i class="fa fa-lock"></i></label>';
    		$output .= '<input id="login-password" type="password" name="password" placeholder="' . get_string('password') . '" />';
    		$output .= '</div>';
    		$output .= '<button type="submit" class="fw">' . get_string('login', 'core') . '</button>';
            $output .= $logintoken;
    		$output .= '</form>';

    		$loginLink = new moodle_url($CFG->wwwroot . '/login/forgot_password.php');
            $signupLink = new moodle_url($CFG->wwwroot . '/login/signup.php');

            $output .= '<p class="login-info"><a href="' . $loginLink . '">' . get_string('forgotten','core') . '</a></p>';

            if ($CFG->registerauth)
            {
                $output .= '<p class="login-info signup"><a href="' . $signupLink . '">' . get_string('startsignup','core') . '</a></p>';
            }
        }

		if ( theme_mb2aofk_theme_setting( $PAGE, 'loginsocial' ) )
		{
			$authsequence = get_enabled_auth_plugins(true); // Get all auths, in sequence.
            $potentialidps = array();
            foreach ($authsequence as $authname)
			{
                $authplugin = get_auth_plugin($authname);
                $potentialidps = array_merge($potentialidps, $authplugin->loginpage_idp_list($PAGE->url->out(false)));
            }

			if (!empty($potentialidps))
			{
     			$output .= '<div class="potentialidps">';
               	$output .= '<h6>' . get_string('potentialidps', 'auth') . '</h6>';
                $output .= '<div class="potentialidplist">';
                foreach ($potentialidps as $idp)
				{
              		$output .= '<div class="potentialidp">';
                   	$output .= '<a class="btn btn-default" ';
                   	$output.= 'href="' . $idp['url']->out() . '" title="' . s($idp['name']) . '">';
                    if (!empty($idp['iconurl']))
					{
                        $output .= '<img src="' . s($idp['iconurl']) . '" width="24" height="24" class="m-r-1"/>';
                    }
                    $output .= s($idp['name']) . '</a></div>';
                }
                $output .= '</div>';
                $output .= '</div>';
            }
		}

        if ( $loginlinks )
        {
            $output .= '</div>'; // end column inner
            $output .= '</div>'; // end column

            $output .= '<div class="col-md-6 order-1 col-loginlinks">';
            $output .= '<div class="col-inner">';
            $output .= theme_mb2aofk_static_content($loginlinks);//theme_mb2aofk_custom_links($loginlinks, 'loginform');
            $output .= '</div>';
            $output .= '</div>';

            $output .= '</div>'; // end row
        }

	}
	elseif ( isloggedin() && ! isguestuser() )
	{
        $logout_link = new moodle_url($CFG->wwwroot . '/login/logout.php', array('sesskey'=>sesskey()));
        $profile_link = new moodle_url($CFG->wwwroot . '/user/profile.php', array('id'=>$USER->id));

        $output .= '<div class="row">';

        $output .= '<div class="col-md-7 col-loginusermenu">';
        $output .= '<div class="col-inner">';
        $output .= $OUTPUT->user_menu();
        $output .= '</div>';
        $output .= '</div>';

        $output .= '<div class="col-md-5 col-loginuserdetails">';
        $output .= '<div class="col-inner">';
        $output .= $OUTPUT->user_picture($USER, array('size' => 80, 'class' => 'welcome_userpicture'));
        $output .= '<p class="loggedinas">' . get_string('loggedinas', 'core', '<strong>' . $USER->firstname . ' ' . $USER->lastname . '</strong> ('  . $USER->username . ')') . '</p>';

        $output .= '<a href="' . $profile_link . '" class="btn btn-default isicon btn-sm">';
        $output .= '<span class="btn-icon"><i class="fa fa-user"></i></span>';
        $output .= '<span class="text1">' . get_string('profile', 'core') . '</span>';
        $output .= '</a>';

        $output .= '<a href="' . $logout_link . '" class="btn btn-primary isicon btn-sm">';
        $output .= '<span class="btn-icon"><i class="fa fa-unlock"></i></span>';
        $output .= '<span class="text1">' . get_string('logout', 'core') . '</span>';
        $output .= '</a>';

        $output .= '</div>';
        $output .= '</div>';

        $output .= '</div>';
	}

	$output .= '</div>';

	return $output;

}





/*
 *
 * Method to get login form
 *
 */
function theme_mb2aofk_login_form_modal ()
{
    global $PAGE;
    $output = '';
    $cls = ' nologinlinks';
    $loginlinks = theme_mb2aofk_theme_setting($PAGE, 'loginlinks');
    $isloggedin = (isloggedin() && !isguestuser());

    if (theme_mb2aofk_is_login($PAGE))
    {
        return ;
    }

    if ($loginlinks || $isloggedin)
    {
        $cls = ' loginlinks';
    }

    if ($isloggedin)
    {
        $cls .= ' isloggedin';
    }

    $output .= '<div id="header-login" class="modal fade' . $cls . '" role="dialog">';
    $output .= '<div class="modal-dialog" role="document">';
    $output .= '<div class="modal-content">';
    $output .= '<div class="theme-modal-container">';
    $output .= '<a class="close-container" href="#" data-dismiss="modal">&times;</a>';
    $output .= theme_mb2aofk_login_form();
    $output .= '</div>';
    $output .= '</div>';
    $output .= '</div>';
    $output .= '</div>';


    return $output;

}







/*
 *
 * Method to set body class
 *
 *
 */
function theme_mb2aofk_settings_arr()
{
    global $CFG;
    $themename = theme_mb2aofk_themename();

    $output = array(
        'all' => array('name'=>get_string('allsettings','theme_mb2aofk'), 'icon'=>'fa fa-cogs', 'url'=> new moodle_url($CFG->wwwroot . '/admin/category.php?category=theme_' . $themename)),
		'general' => array('name'=>get_string('settingsgeneral','theme_mb2aofk'), 'icon'=>'fa fa-dashboard', 'url'=>''),
		'features' => array('name'=>get_string('settingsfeatures','theme_mb2aofk'), 'icon'=>'fa fa-rocket', 'url'=>''),
		'fonts' => array('name'=>get_string('settingsfonts','theme_mb2aofk'), 'icon'=>'fa fa-font', 'url'=>''),
		'nav' => array('name'=>get_string('settingsnav','theme_mb2aofk'), 'icon'=>'fa fa-navicon', 'url'=>''),
		'social' => array('name'=>get_string('settingssocial','theme_mb2aofk'), 'icon'=>'fa fa-share-alt', 'url'=>''),
		'style' => array('name'=>get_string('settingsstyle','theme_mb2aofk'), 'icon'=>'fa fa-paint-brush', 'url'=>''),
		'typography' => array('name'=>get_string('settingstypography','theme_mb2aofk'), 'icon'=>'fa fa-text-height', 'url'=>''),
        'siteadmin' => array('name'=>get_string('administrationsite'), 'icon'=>'fa fa-sitemap', 'url'=> new moodle_url( $CFG->wwwroot . '/admin/search.php' ))
	);

	return $output;

}
